@@ -1,7 +1,7 @@
 from django.contrib.auth import get_user_model
-from django.contrib.auth.models import Permission
 from django.core.exceptions import ValidationError
-from django.test import TestCase
+from django.test import TestCase, override_settings
+from django.urls import reverse
 from swapper import load_model
 
 from .utils import TestOrganizationMixin
@@ -9,7 +9,7 @@ from .utils import TestOrganizationMixin
 Organization = load_model('openwisp_users', 'Organization')
 OrganizationUser = load_model('openwisp_users', 'OrganizationUser')
 OrganizationOwner = load_model('openwisp_users', 'OrganizationOwner')
-Group = load_model('openwisp_users', 'Group')
+EmailConfirmation = load_model('account', 'EmailConfirmation')
 User = get_user_model()
 
 
@@ -205,64 +205,6 @@ class TestUsers(TestOrganizationMixin, TestCase):
         self.assertIsNone(user2.phone_number)
         self.assertEqual(self.user_model.objects.filter(phone_number=None).count(), 2)
 
-    def test_cache_user_permission(self):
-        user = self.user_model(
-            username='user', email='email1@email.com', password='user1', is_staff=True
-        )
-        user.full_clean()
-        user.save()
-        group = Group.objects.filter(name='Administrator')
-        user.groups.set(group)
-
-        with self.subTest('Test cached permissions'):
-            with self.assertNumQueries(0):
-                user.permissions
-            self.assertEqual(user.get_all_permissions(), user.permissions)
-
-        with self.subTest('Test group permissions changed'):
-            self.assertIn('account.view_emailaddress', user.permissions)
-            permission = Permission.objects.get(codename='view_emailaddress')
-            g = group.first()
-            g.permissions.remove(permission.pk)
-            g.refresh_from_db()
-            self.assertNotIn('account.view_emailaddress', user.permissions)
-
-        with self.subTest('Test group changed'):
-            user.groups.remove(group.first().pk)
-            user.groups.set(Group.objects.filter(name='Operator'))
-            with self.assertNumQueries(0):
-                self.assertEqual(user.get_all_permissions(), user.permissions)
-
-        with self.subTest('Test user permission changed'):
-            permission = Permission.objects.filter(codename='add_organization')
-            user.user_permissions.add(*permission)
-            with self.assertNumQueries(0):
-                self.assertEqual(user.get_all_permissions(), user.permissions)
-
-    def test_operator_has_permission(self):
-        app_label = 'account'
-        user = self.user_model(
-            username='user', email='email1@email.com', password='user1', is_staff=True
-        )
-        user.full_clean()
-        user.save()
-        group = Group.objects.filter(name='Administrator')
-        user.groups.set(group)
-        self.assertFalse(user.has_permission(f'{app_label}.view_wrong'))
-        self.assertTrue(user.has_permission(f'{app_label}.view_emailaddress'))
-
-    def test_superuser_has_permission(self):
-        user = self.user_model(
-            username='superuser',
-            email='email@email.com',
-            password='test',
-            is_staff=True,
-            is_superuser=True,
-        )
-        user.full_clean()
-        user.save()
-        self.assertTrue(user.has_permission('not_found.not_found'))
-
     def test_user_get_pk(self):
         org = Organization.objects.first()
         pk = str(org.pk)
@@ -302,3 +244,27 @@ class TestUsers(TestOrganizationMixin, TestCase):
             org_user2.full_clean()
             org_user2.save()
             self.assertEqual(org_user2.is_admin, False)
+
+    @override_settings(
+        ACCOUNT_EMAIL_CONFIRMATION_ANONYMOUS_REDIRECT_URL='email_confirmation_success',
+        ACCOUNT_EMAIL_CONFIRMATION_AUTHENTICATED_REDIRECT_URL=(
+            'email_confirmation_success'
+        ),
+    )
+    def test_email_verification_success(self):
+        user = self._create_user()
+        email_address = user.emailaddress_set.first()
+        email_confirmation = EmailConfirmation.create(email_address)
+        email_confirmation.send()
+        url = reverse('account_confirm_email', args=[email_confirmation.key])
+        response = self.client.post(url, follow=True)
+        self.assertContains(response, 'Your email has been verified successfully.')
+        self.assertContains(response, 'This web page can be closed.')
+
+    @override_settings(ACCOUNT_LOGOUT_REDIRECT_URL='logout_success')
+    def test_logout_success(self):
+        user = self._create_user()
+        self.client.force_login(user)
+        response = self.client.post(reverse('account_logout'), follow=True)
+        self.assertContains(response, 'Logout successful.')
+        self.assertContains(response, 'This web page can be closed.')
